---
name: Feature request
about: Suggest an idea for this project
title: "[Feature]"
labels: enhancement
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want things to look like.

**Describe proposed solutions you've considered**
A clear and concise description of proposed solutions you considered.
If you can argue for and against them so we can pick the best one, please do.

**Additional context**
Add any other context or screenshots about the feature request here.
